@@ -273,7 +273,7 @@ def _generate_tool_implementation(tool: Dict[str, Any]) -> str:
             "status": "not_implemented",
             "message": f"TODO: Implement {tool_name}",
             "tool": "{tool_name}",
-            "description": "{tool_desc}",
+            "description": {json.dumps(tool_desc)},
             "input": locals()  # Shows all parameters for debugging
         }}
         
@@ -297,8 +297,10 @@ async def _analyze_and_plan(requirements: str, ctx: Context, include_resources:
     await ctx.info("📋 Creating boilerplate structure for Claude to customize...")
     
     # Create a generic plan with placeholders
+    # Clean up requirements for description - remove newlines and excessive spaces
+    clean_requirements = ' '.join(requirements.split())[:100]
     plan = {
-        "description": f"MCP server for: {requirements[:100]}{'...' if len(requirements) > 100 else ''}",
+        "description": f"MCP server for: {clean_requirements}{'...' if len(requirements) > 100 else ''}",
         "tools": [
             {
                 "name": "tool_one",
@@ -403,7 +405,7 @@ def _generate_fallback_implementation(tool: Dict[str, Any]) -> str:
         # Implementation based on tool purpose
         result = {{
             "tool": "{tool_name}",
-            "description": "{tool_desc}",
+            "description": {json.dumps(tool_desc)},
             "status": "success",
             "message": "Tool executed successfully",
             "timestamp": datetime.now().isoformat()
